Overview
========

The MaxMind DXL Geolocation service provides a service on the DXL fabric that allows IP or hostname Geolocation lookups in a MaxMind database.

The MaxMind database can either be statically designated or automatically downloaded and updated from MaxMind.